#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pattern-arrows
version:              0.0.2
visibility:           public
id:                   pattern-arrows-0.0.2-KJGlimwoizi7eRKbINhWuR
key:                  pattern-arrows-0.0.2-KJGlimwoizi7eRKbINhWuR
license:              MIT
copyright:            (c) Phil Freeman 2013
maintainer:           Phil Freeman <paf31@cantab.net>
author:               Phil Freeman <paf31@cantab.net>
stability:            experimental
homepage:
    http://blog.functorial.com/posts/2013-10-27-Pretty-Printing-Arrows.html

synopsis:             Arrows for Pretty Printing
description:
    A library for generating concise pretty printers based on precedence rules.

category:             Text, Combinators, Pretty Printer
abi:                  a6bc4c471e00d58129d7c746f792cfca
exposed:              True
exposed-modules:      Control.PatternArrows
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pattern-arrows-0.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pattern-arrows-0.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pattern-arrows-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pattern-arrows
hs-libraries:         HSpattern-arrows-0.0.2-KJGlimwoizi7eRKbINhWuR
depends:              base-4.18.2.1 mtl-2.3.1
haddock-interfaces:
    /usr/share/doc/haskell-pattern-arrows/html/pattern-arrows.haddock

haddock-html:         /usr/share/doc/haskell-pattern-arrows/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

